{% load static %}
<link href="{% static 'material/fonts/material-design-icons/material-icons.css' %}"  rel="stylesheet">
<link href="{% static 'material/fonts/roboto/style.css' %}" rel="stylesheet">
{% if not debug %}
<link href="{% static 'material/css/materialize.frontend.min.css' %}" rel="stylesheet">
{% else %}
<link href="{% static 'material/css/materialize.css' %}" rel="stylesheet">
<link href="{% static 'material/css/materialize.forms.css' %}" rel="stylesheet">
<link href="{% static 'material/css/materialize.frontend.css' %}" rel="stylesheet">
<link href="{% static 'material/css/jquery.datetimepicker.css' %}" rel="stylesheet">
<link href="{% static 'material/css/responsive.dataTables.css' %}" rel="stylesheet">
<link href="{% static 'material/css/fixedHeader.dataTables.css' %}" rel="stylesheet">
<link href="{% static 'material/css/perfect-scrollbar.css' %}" rel="stylesheet">
{% endif %}
