/* materialize.css variables */ 
$primary-color: #424242;
$primary-color-light: lighten($primary-color, 15%);
$primary-color-dark: darken($primary-color, 15%);

$secondary-color: #37474f;                           // blue-grey
$success-color: #607d8b;                             // green
$error-color: #f44336;                               // red
$link-color: #039be5;                                // light-blue darken-1


/* django-material variables */
// $logo-background-color: $primary-color-dark;

/* fixes */
$input-margin: 0 0 15px 0; //  0 0 20px 0 !default   // label data-error/data-success placeholders not used
