{% load static i18n %}
<script src="{% static 'material/js/jquery.datetimepicker.full.js' %}"></script>
<script src="{% static 'material/js/jquery.formset.js' %}"></script>
<script src="{% static 'material/js/materialize.js' %}"></script>
<script src="{% static 'material/js/materialize.forms.js' %}"></script>
