{% load material_form_internal %}
<div class="layout-row row">{% for element, span in parent.container_12 %}<div class="col s12 m{{ span }}">{% render element %}{% endrender %}</div>{% endfor %}</div>
