/* materialize.css variables */
/* fixes */
/* FORM LAYOUT */
form .row {
  margin-bottom: 0px;
  margin-left: -0.75rem;
  margin-right: -0.75rem; }

/* COMMON ELEMENTS */
form .help-block {
  line-height: 12px;
  position: relative;
  top: -10px;
  color: rgba(0, 0, 0, 0.6);
  font-size: 75%; }

form .error {
  line-height: 12px;
  position: relative;
  top: -10px;
  color: #F44336; }

/* INPUT FIELD */
.input-field {
  margin-bottom: 0; }
  .input-field label {
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden; }
  .input-field.has-error .prefix {
    color: #F44336; }
  .input-field .prefix {
    line-height: 45px; }
    .input-field .prefix ~ label {
      width: calc(100% - 21px - 3rem); }
    .input-field .prefix ~ .errors .error {
      margin-left: 3rem; }
  .input-field .input-field-action {
    position: absolute;
    top: 0;
    right: 0;
    color: #555;
    padding: 0 0.75rem;
    line-height: 3rem;
    background: white; }
    .input-field .input-field-action i.material-icons {
      vertical-align: middle; }
  .input-field input[type=number] {
    -moz-appearance: textfield; }
  .input-field .input-field-action {
    position: absolute;
    top: 0;
    right: 0;
    color: #555;
    padding: 0 0.75rem;
    line-height: 3rem;
    background: white; }
    .input-field .input-field-action i.material-icons {
      vertical-align: middle; }
  .input-field ::-webkit-inner-spin-button {
    -webkit-appearance: none; }
  .input-field ::-webkit-outer-spin-button {
    -webkit-appearance: none; }

input:-webkit-autofill + label {
  transform: translateY(-140%); }

/* SELECT FIELD */
select.material-ignore {
  display: block; }

.select-field .prefix {
  position: absolute;
  width: 3rem;
  font-size: 2rem;
  margin-top: 25px;
  transition: color .2s; }
  .select-field .prefix ~ label {
    margin-left: 3rem; }

.select-field.has-error input {
  border-bottom: 1px solid #F44336;
  box-shadow: 0 1px 0 0 #F44336; }

.select-field .select-wrapper {
  margin-top: 0px; }
  .select-field .select-wrapper input.select-dropdown {
    margin-top: -7px; }
  .select-field .select-wrapper .caret {
    z-index: 0; }

/* CHECHBOX FIELD */
.checkbox-field {
  line-height: 35px; }
  .checkbox-field label {
    color: rgba(0, 0, 0, 0.84); }
  .checkbox-field .prefix {
    position: relative;
    top: 5px;
    width: 2.5rem;
    font-size: 2rem; }
  .checkbox-field .help-block {
    padding-top: 5px;
    padding-left: 35px;
    font-size: 12px;
    line-height: 16px;
    display: block; }

/* RADIO FIELD */
.radio-field .radio {
  padding-top: 10px; }

.radio-field .error, .radio-field .help-block {
  top: 0px;
  left: 5px; }

.radio-field label.item-label {
  font-size: 14px;
  color: rgba(0, 0, 0, 0.84); }

.radio-field .prefix {
  position: relative;
  top: 5px;
  width: 2.5rem;
  font-size: 2rem; }
  .radio-field .prefix ~ label {
    width: calc(100% - 21px - 3rem); }

.radio-field .inline {
  margin-top: 10px; }
  .radio-field .inline .radio {
    display: inline;
    margin-right: 20px; }

/* FILE FIELD */
.file-field .btn,
.file-field .btn-large {
  left: auto; }

.file-field-clear {
  float: right; }
  .file-field-clear label {
    margin-right: 25px;
    width: auto; }

/* FORMSET*/
.formset-field h5 {
  font-size: 1.2rem;
  padding-bottom: 0.2rem;
  border-bottom: 2px solid black;
  margin-bottom: 0px; }

.formset-field td {
  vertical-align: top;
  padding-bottom: 0px;
  padding-top: 5px; }

.formset-field td:first-child {
  padding-left: 0px; }

.formset-field td:last-child {
  padding-right: 0px; }

/* AUTOCOMPLETE */
.autocomplete-suggestions {
  background-color: #fff;
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2);
  max-height: 650px;
  min-width: 100px;
  overflow-y: auto;
  will-change: width, height;
  z-index: 999; }
  .autocomplete-suggestions .autocomplete-suggestion,
  .autocomplete-suggestions .autocomplete-no-suggestion {
    clear: both;
    color: #26a69a;
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    display: block;
    font-size: 16px;
    line-height: 1.5rem;
    line-height: 22px;
    min-height: 50px;
    padding: 14px 16px;
    text-align: left;
    text-transform: none;
    width: 100%; }
    .autocomplete-suggestions .autocomplete-suggestion.autocomplete-selected,
    .autocomplete-suggestions .autocomplete-no-suggestion.autocomplete-selected {
      background-color: #eee; }

.autocomplete-field input.invalid-selection {
  color: #f44336; }

.autocomplete-field .chips.focus {
  border-bottom: 1px solid #1976d2;
  box-shadow: 0 1px 0 0 #1976d2; }

.autocomplete-field .chips .input {
  width: auto !important; }
