@charset "UTF-8";

// Mixins
@import "materialize-css/sass/components/color-variables";
@import "materialize-css/sass/components/color-classes";

// Variables;
@import "variables";
@import "materialize-css/sass/components/variables";

// Reset
@import "materialize-css/sass/components/normalize";

// components
@import "materialize-css/sass/components/global";
@import "materialize-css/sass/components/badges";
@import "materialize-css/sass/components/icons-material-design";
@import "materialize-css/sass/components/grid";
@import "materialize-css/sass/components/navbar";
@import "materialize-css/sass/components/typography";
@import "materialize-css/sass/components/transitions";
@import "materialize-css/sass/components/cards";
@import "materialize-css/sass/components/toast";
@import "materialize-css/sass/components/tabs";
@import "materialize-css/sass/components/tooltip";
@import "materialize-css/sass/components/buttons";
@import "materialize-css/sass/components/dropdown";
@import "materialize-css/sass/components/waves";
@import "materialize-css/sass/components/modal";
@import "materialize-css/sass/components/collapsible";
@import "materialize-css/sass/components/chips";
@import "materialize-css/sass/components/materialbox";
@import "materialize-css/sass/components/forms/forms";
@import "materialize-css/sass/components/table_of_contents";
@import "materialize-css/sass/components/sidenav";
@import "materialize-css/sass/components/preloader";
@import "materialize-css/sass/components/slider";
@import "materialize-css/sass/components/carousel";
@import "materialize-css/sass/components/tapTarget";
@import "materialize-css/sass/components/pulse";
@import "materialize-css/sass/components/datepicker";
@import "materialize-css/sass/components/timepicker";
