@font-face {
  font-family: "Roboto";
  src: url("fonts/Roboto-MediumItalic.eot");
  src: local("Roboto Medium Italic"), local("Roboto-MediumItalic"),
    url("fonts/Roboto-MediumItalic.eot?#iefix") format("embedded-opentype"),
    url("fonts/Roboto-MediumItalic.woff2") format("woff2"),
    url("fonts/Roboto-MediumItalic.woff") format("woff"),
    url("fonts/Roboto-MediumItalic.ttf") format("truetype");
  font-weight: 500;
  font-style: italic;
}
