{% load i18n material_form material_form_internal %}
{% get_current_language as LANGUAGE_CODE %}
{% get_language_info for LANGUAGE_CODE as lang %}
{% part bound_field.field %}{% part field label %}
{% endpart %}
<div class="row" id="id_{{ bound_field.html_name }}_container">
    <div class="col s12">
        <label{% attrs bound_field 'label' %}
            for="{{ bound_field.id_for_label }}"
        {% endattrs %}>{{ bound_field.label }}</label>
    </div>
    <div{% attrs bound_field 'group' %}
        class="input-field col s6{% if field.required %} required{% endif %}{% if bound_field.errors %} has-error{% endif %}"
        style="margin-top:-7px"
    {% endattrs %}>
        {% part field prefix %}{% endpart %}{% part field control %}
        <i class="material-icons prefix">view_module</i>
        <input{% attrs bound_field 'widget_date' default field.widget.attrs %}
            id="id_{{ bound_field.html_name }}_0"
            name="{{ bound_field.html_name }}_0"
            type="text"
            data-date-format="{{ field.fields.0|jquery_datepicker_format }}"
            data-form-control="date"
            data-lang="{{ lang.code|default:'en' }}"
            {% if bound_field.errors %}class="invalid"{% endif %}
            {% if bound_field.value %} value="{{ bound_field|multiwidget_value:0|datepicker_value:field.fields.0.input_formats.0 }}"{% endif %}
        {% endattrs %}>
        {% endpart %}{% part field help_text %}
        {% part field errors %}
        {% if bound_field.errors %}
            {% include  'material/field_errors.html' %}
        {% endif %}
        {% endpart %}{% if field.help_text %}
        <div class="help-block">{{ bound_field.help_text|safe }}</div>
        {% endif %}
        {% endpart %}{{ hidden_initial }}
    </div>
    <div class="input-field col s6{% if field.required %} required{% endif %}{% if bound_field.errors %} has-error{% endif %}"
         style="margin-top:-7px">
        <i class="material-icons prefix">query_builder</i>
        <input{% attrs bound_field 'widget_time' default field.widget.attrs %}
            id="id_{{ bound_field.html_name }}_1"
            name="{{ bound_field.html_name }}_1"
            type="text"
            data-date-format="{{ field.fields.1|jquery_datepicker_format }}"
            data-form-control="time"
            data-lang="{{ lang.code|default:'en' }}"
            {% if bound_field.errors %}class="invalid"{% endif %}
            {% if bound_field.value %} value="{{ bound_field|multiwidget_value:1|datepicker_value:field.fields.1.input_formats.0 }}"{% endif %}
         {% endattrs %}>
    </div>
</div>{% endpart %}
