{% load static %}
<link href="{% static 'material/fonts/material-design-icons/material-icons.css' %}" rel="stylesheet">
<link href="{% static 'material/fonts/roboto/style.css' %}" rel="stylesheet">

<link href="{% static 'material/css/materialize.css' %}" rel="stylesheet">
<link href="{% static 'material/css/materialize.forms.css' %}" rel="stylesheet">
<link href="{% static 'material/css/jquery.datetimepicker.css' %}" rel="stylesheet">
