@font-face {
    font-family: 'Roboto';
    src: url('fonts/Roboto-Bold.eot');
    src: local('Roboto Bold'), local('Roboto-Bold'),
        url('fonts/Roboto-Bold.eot?#iefix') format('embedded-opentype'),
        url('fonts/Roboto-Bold.woff2') format('woff2'),
        url('fonts/Roboto-Bold.woff') format('woff'),
        url('fonts/Roboto-Bold.ttf') format('truetype');
    font-weight: bold;
    font-style: normal;
}
