/* materialize.css variables */
/* fixes */
/* MAIN */
html, body, main {
  height: 100%; }

body {
  background: #efefef; }

th {
  font-weight: 300; }

/* REGISTRATION */
.registration {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  background-size: cover !important; }
  .registration .sidebar {
    align-items: center;
    align-self: flex-start;
    background: white;
    display: flex;
    flex-direction: column;
    height: 100%;
    justify-content: center;
    min-width: 400px;
    max-width: 400px;
    opacity: 0.85;
    text-align: center; }
    .registration .sidebar h4 {
      font-weight: 300; }
    .registration .sidebar form {
      width: 90%; }
  .registration .logo {
    -ms-grid-row-align: center;
        align-self: center;
    width: 100%;
    text-align: center;
    color: white; }
    .registration .logo .logo__icon {
      font-size: 20rem; }
  .registration .action button {
    width: calc(100% - 3rem);
    margin-top: 1.5rem; }

@media only screen and (max-width: 600px) {
  .registration .logo {
    display: none; }
  .registration .sidebar {
    width: 100%; } }

/* LAYOUT */
@media only screen and (min-width: 993px) {
  html {
    overflow-y: scroll; }
  main, footer {
    margin-left: 300px; }
  nav {
    padding-left: 40px; } }

.content {
  display: flex;
  max-width: 100%;
  padding-bottom: 50px; }
  .content > .row {
    width: 100%; }

.left-panel {
  flex-basis: 80%;
  margin-left: 0.375rem; }
  .left-panel.wide {
    flex-basis: 100%;
    margin-right: 0.375rem; }
  .left-panel > .card {
    margin-bottom: 0.375rem; }

.right-panel {
  flex-basis: 20%;
  min-width: 250px;
  margin-left: 0.375rem;
  margin-right: 0.375rem; }
  .right-panel > .card {
    margin-bottom: 0.5rem; }

@media only screen and (max-width: 993px) {
  .left-panel {
    flex-basis: 100%;
    width: 100%;
    margin-left: 0;
    margin-right: 0; }
  .left-panel > .card {
    margin-top: 1px; }
  .right-panel {
    display: none; } }

/* ALERTS */
.toast {
  justify-content: flex-start; }

.toast a {
  color: white; }
  .toast a.alert-success {
    background-color: #43a047; }
  .toast a.alert-info {
    background-color: #0277bd; }
  .toast a.alert-warning {
    background-color: #ef6c00;
    color: #fff; }
  .toast a.alert-error {
    background-color: #bf360c; }

/* DEFAULT ICONS */
.admin-appicon:before {
  content: "\e8b9"; }

.admin-modelicon:before {
  content: "\e8b9"; }

/* SIDEBAR */
.side-nav.fixed {
  overflow-y: hidden; }
  .side-nav.fixed .userView {
    min-height: 175px; }
  .side-nav.fixed li {
    min-height: 48px; }
  .side-nav.fixed > li.last {
    padding-bottom: 58px; }
  .side-nav.fixed .collapsible-body {
    padding: 0; }
    .side-nav.fixed .collapsible-body li a {
      padding-left: 70px; }

/* TOPBAR */
nav.topbar {
  box-shadow: none;
  height: 54px;
  line-height: 54px; }
  nav.topbar .brand-logo {
    font-weight: 100;
    font-size: 2.5rem;
    top: 5px; }
  nav.topbar i,
  nav.topbar a.button-collapse,
  nav.topbar a.button-collapse i {
    height: 54px;
    line-height: 54px; }
  nav.topbar .brand-logo {
    font-weight: 100;
    font-size: 2.5rem;
    top: 5px; }

.popup nav.topbar {
  height: 64px; }

/* BREADCRUMBS */
nav.breadcrumbs {
  height: 48px;
  line-height: 48px;
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 0px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2); }
  nav.breadcrumbs a:first-child {
    padding-left: 0px; }
  nav.breadcrumbs a {
    font-size: 1rem;
    color: rgba(255, 255, 255, 0.7); }
  nav.breadcrumbs a.active {
    color: white; }
  nav.breadcrumbs a:not(:first-child):before {
    content: '\E5CC';
    color: rgba(255, 255, 255, 0.7);
    vertical-align: top;
    display: inline-block;
    font-family: 'Material Icons';
    font-weight: normal;
    font-style: normal;
    font-size: 20px;
    margin: 0 5px 0 4px;
    -webkit-font-smoothing: antialiased; }

@media only screen and (max-width: 992px) {
  nav.breadcrumbs {
    text-align: center; } }

@media only screen and (max-width: 600px) {
  nav.breadcrumbs {
    white-space: nowrap; }
    nav.breadcrumbs .nav-wrapper {
      width: 100%;
      overflow-x: hidden;
      padding: 0 20px 0 10px;
      text-overflow: ellipsis; } }

/* APP INDEX PAGE */
.app-list {
  padding: 5px;
  -moz-column-gap: 0;
  column-gap: 0;
  -moz-column-count: 3;
  column-count: 3; }
  .app-list .app {
    page-break-inside: avoid;
    padding: 5px; }
    .app-list .app .card {
      margin: 0px; }
      .app-list .app .card .app-item {
        padding-left: 0px !important; }
        .app-list .app .card .app-item i {
          font-size: 48px; }
        .app-list .app .card .app-item a {
          background: #f5f5f5;
          color: #8d6153;
          display: block;
          border-radius: 4px;
          padding: 30px 0px;
          text-align: center;
          position: relative;
          height: 130px;
          margin-top: 10px;
          margin-bottom: 10px;
          margin-right: 0px; }
          .app-list .app .card .app-item a h6 {
            overflow: hidden;
            text-overflow: ellipsis;
            word-wrap: break-word;
            padding: 5px; }

@media (max-width: 1401px) {
  .app-list {
    -moz-column-count: 2;
    column-count: 2;
    padding: 0px; } }

@media (max-width: 600px) {
  .app-list {
    -moz-column-count: 1;
    column-count: 1;
    padding: 0px; } }

/* CHANGE LIST PAGE */
.actions-card .card-title {
  font-size: 18px;
  text-transform: uppercase;
  margin-bottom: -10px; }

.actions-card .card-content {
  padding: 20px;
  padding-top: 5px; }

.actions-card .row {
  margin-bottom: 0px;
  margin-left: -0.75rem;
  margin-right: -0.75rem; }

.actions-card span.action-counter,
.actions-card span.all,
.actions-card span.question,
.actions-card span.clear {
  font-size: 12px; }

.actions-card .card-action {
  padding: 10px; }

.filters-card {
  overflow: initial; }
  .filters-card .card-title {
    font-size: 18px;
    text-transform: uppercase; }
  .filters-card .card-content {
    padding: 20px;
    padding-top: 5px; }
  .filters-card .row {
    margin-bottom: 0px;
    margin-left: -0.75rem;
    margin-right: -0.75rem; }
  .filters-card a {
    margin-right: 0; }
  .filters-card #changelist-search-button {
    z-index: 1000;
    position: absolute;
    right: 15px;
    top: 15px; }
    .filters-card #changelist-search-button i.material-icons {
      font-size: 18px; }

/* DATATABLE */
.fixedHeader th {
  background: white; }

.fixedHeader-floating th:first-child,
.fixedHeader-floating td:first-child {
  padding-left: 24px; }

.fixedHeader-floating .action-checkbox label {
  display: none; }

.fixedHeader-floating thead th a,
.results table thead a {
  color: black;
  font-weight: 200;
  text-transform: none; }

.results table th, .results table td {
  vertical-align: top; }

.results table.collapsed td, .results table.collapsed th {
  vertical-align: top; }

.results table thead th {
  white-space: nowrap; }

.results table tbody a {
  color: #039be5;
  text-transform: none; }

.results table.dataTable tr.child ul li {
  white-space: normal; }

.results table tr th:first-child,
.results table tr td:first-child {
  padding-left: 24px; }

.results table tr th:last-child,
.results table tr td:last-child {
  padding-right: 24px; }

.results table tr .action-checkbox {
  width: 50px; }

.fixedHeader-floating thead i.material-icons,
.results thead i.material-icons {
  line-height: 15px;
  margin-left: -15px;
  font-size: 15px;
  position: relative;
  top: 3px; }

@media only screen and (max-width: 992px) {
  .fixedHeader-floating thead i.material-icons,
  .results thead i.material-icons {
    display: none; } }

@media only screen and (max-height: 400px) {
  .fixedHeader {
    display: none; } }

/* ACTION BUTTON */
@media only screen and (max-height: 400px) {
  .fixed-action-btn {
    display: none; } }

/*  CHANGE FORM */
.change-form a {
  color: #039be5;
  text-transform: none; }

.change-form .form-title {
  font-size: 1.5rem;
  font-weight: 200;
  margin-bottom: 10px;
  margin-top: 0px; }

.change-form .errornote {
  color: #F44336; }

.change-form .section {
  padding-top: 0px;
  padding-bottom: 0px; }
  .change-form .section h5 {
    font-size: 1.2rem;
    border-bottom: 2px solid #555;
    padding-bottom: 0.5rem; }

.change-form .checkbox-field {
  padding-top: 15px;
  padding-bottom: 15px; }

.change-form .formset-field h5 {
  font-size: 1.2rem;
  border-bottom: 2px solid #555;
  padding-bottom: 0.5rem; }

.change-form .formset-field td {
  padding: 5px; }

.change-form .related-widget-wrapper label.related-widget-label {
  font-size: 15px;
  color: black;
  font-weight: 200; }

.change-form .related-widget-wrapper .related-widget-wrapper-link {
  opacity: 0.3; }

.change-form .related-widget-wrapper .related-widget-wrapper-link:link {
  opacity: 1; }

.change-form .multiselect .selector-chooser {
  text-align: center; }
  .change-form .multiselect .selector-chooser li {
    margin-bottom: 5px; }

.change-form .multiselect .selector-add,
.change-form .multiselect .selector-remove {
  background-color: #8d6153; }

@media only screen and (min-width: 601px) {
  .change-form .multiselect {
    margin-bottom: 40px; }
    .change-form .multiselect hr {
      color: #eee;
      background-color: #eee;
      height: 1px;
      border: none; }
    .change-form .multiselect .selector-available {
      width: calc(50% - 30px);
      width: -moz-calc(50% - 30px); }
    .change-form .multiselect .selector-available input,
    .change-form .multiselect .selector-chosen input {
      margin-bottom: 0px; }
    .change-form .multiselect .selector-available select {
      height: 120px; }
    .change-form .multiselect .selector-chooser {
      width: 60px;
      padding-top: 40px; }
    .change-form .multiselect .selector-chosen {
      width: calc(50% - 30px);
      width: -moz-calc(50% - 30px); }
      .change-form .multiselect .selector-chosen select {
        height: 120px; } }

@media only screen and (max-width: 600px) {
  .change-form .multiselect .selector-available select {
    height: 120px; }
  .change-form .multiselect .selector-chooser li {
    display: inline; }
  .change-form .multiselect .selector-chooser .selector-add i,
  .change-form .multiselect .selector-chooser .selector-remove i {
    transform: rotate(90deg);
    position: relative;
    top: 10px;
    left: 7px; } }

.change-form .vForeignKeyRawIdAdminField + label,
.change-form .vManyToManyRawIdAdminField + label {
  width: calc(100% - 110px); }

.change-form .input-group {
  display: table; }

.change-form .input-group > div, .change-form .input-group input, .change-form .suffix {
  display: table-cell; }

.change-form .suffix {
  padding-left: 10px;
  width: 1%; }

.change-form .readonly-password-field {
  margin-top: 10px;
  margin-bottom: 10px;
  color: rgba(0, 0, 0, 0.3); }
  .change-form .readonly-password-field div {
    margin-top: 10px;
    margin-bottom: 15px;
    padding-bottom: 10px;
    border-bottom: 1px solid rgba(0, 0, 0, 0.3); }
