{% extends "material/frontend/base_lockscreen.html" %}
{% load i18n %}

{% block title %}403 {% trans 'Access Forbidden' %} - {{ block.super }}{% endblock %}


{% block content %}
<div class="row">
    <div class="col s12">
        {% trans 'Access Forbidden' %}
    </div>
    <div class="col s12">
        {% if request.user.is_anonymous %}
        {% trans 'You are not logged in' %}
        {% else %}
        {% blocktrans with user=request.user|default:"You" %}{{ user }} have no rights to access to the page{% endblocktrans %}
        {% endif %}
    </div>
</div>
<div class="row">
    <div class="col s12">
        <a href="{% url 'login' %}?next={{ request.path }}" class="btn btn-primary white-text">{% trans 'Log in' %}</a>
    </div>
</div>
{% endblock %}

{% block icon %}lock{% endblock %}
