{% extends "material/frontend/base_lockscreen.html" %}
{% load i18n %}

{% block title %}400 {% trans 'Bad Request' %} - {{ block.super }}{% endblock %}

{% block page_title %}400<br/>{% trans 'Bad Request' %}{% endblock %}

{% block content %}
<div class="row">
    <div class="col s12">
        <a href="/" class="btn btn-primary white-text">{% trans 'View site' %}</a>
    </div>
</div>
{% endblock %}

{% block icon %}error{% endblock %}
