{% load material_form material_form_internal l10n %}
{% part bound_field.field %}<div class="row">
    <div{% attrs bound_field 'group' %}
        id="id_{{ bound_field.html_name }}_container"
        class="col s12{% if field.required %} required{% endif %}{% if bound_field.errors %} has-error{% endif %}"
    {% endattrs %}>
        {% part field label %}
        <label{% attrs bound_field 'label' %}
            for="{{ bound_field.id_for_label }}"
            {% if bound_field.value != None and bound_field.value != '' %}class="active"{% endif %}
        {% endattrs %}>{{ bound_field.label }}</label>
        {% endpart %}
        {% part field prefix %}{% endpart %}{% part field control %}
        <p class="range-field">
        <input{% attrs bound_field 'widget' default field.widget.attrs %}
            id="id_{{ bound_field.html_name }}"
            name="{{ bound_field.html_name }}"
            type="{{ field.widget.input_type }}"
            {% if bound_field.errors %}class="invalid"{% endif %}
            {% if bound_field.value != None %}value="{{ bound_field.value|unlocalize }}"{% endif %}
        {% endattrs %}></p>{% endpart %}
        {% part field help_text %}{% if field.help_text %}
        <div class="help-block">{{ bound_field.help_text|safe }}</div>
        {% endif %}
        {% endpart %}{% part field errors %}
        {% if bound_field.errors %}{% include  'material/field_errors.html' %}{% endif %}
        {% endpart %}{{ hidden_initial }}
    </div>
</div>{% endpart %}
